<?php

namespace App\Controller;

require_once __DIR__ . "/../react-display.php";

use App\Gateway\FormResultGateway;
use App\Http\HttpRequest;
use App\Http\HttpResponse;
use App\Http\ViewHttpResponse;
use App\Validation\Validators;

class SampleFormController {

    private FormResultGateway $gateway;

    /**
     * @param FormResultGateway $gateway
     */
    public function __construct(FormResultGateway $gateway) {
        $this->gateway = $gateway;
    }


    public function displayFormReact(): HttpResponse {
        return ViewHttpResponse::react("views/SampleForm.tsx", []);
    }

    public function displayFormTwig(): HttpResponse {
        return ViewHttpResponse::twig('sample_form.html.twig', []);
    }

    private function submitForm(array $form, callable $response): HttpResponse {
        return Control::runCheckedFrom($form, [
            "name" => [Validators::lenBetween(0, 32), Validators::name("Le nom ne peut contenir que des lettres, des chiffres et des accents")],
            "description" => [Validators::lenBetween(0, 512)]
        ], function (HttpRequest $req) use ($response) {
            $description = htmlspecialchars($req["description"]);
            $this->gateway->insert($req["name"], $description);
            $results = ["results" => $this->gateway->listResults()];
            return call_user_func_array($response, [$results]);
        }, false);
    }

    public function submitFormTwig(array $form): HttpResponse {
        return $this->submitForm($form, fn(array $results) => ViewHttpResponse::twig('display_results.html.twig', $results));
    }

    public function submitFormReact(array $form): HttpResponse {
        return $this->submitForm($form, fn(array $results) => ViewHttpResponse::react('views/DisplayResults.tsx', $results));
    }
}