<?php

namespace App\Data;

use http\Exception\InvalidArgumentException;

class Color {
    /**
     * @var int 6 bytes unsigned int that represents an RGB color
     */
    private int $value;

    /**
     * @param int $value 6 bytes unsigned int that represents an RGB color
     * @throws \InvalidArgumentException if the value is negative or greater than 0xFFFFFF
     */
    private function __constructor(int $value) {
        $this->value = $value;
    }

    /**
     * @return int
     */
    public function getValue(): int {
        return $this->value;
    }

    public static function from(int $value): Color {
        $color = self::tryFrom($value);
        if ($color == null) {
            throw new InvalidArgumentException("int color value is invalid, must be positive and lower than 0xFFFFFF");
        }
        return $color;
    }

    public static function tryFrom(int $value): ?Color {
        if ($value < 0 || $value > 0xFFFFFF) {
            return null;
        }
        return new Color($value);
    }

}