<?php

namespace App\Http;

class ViewHttpResponse extends HttpResponse {

    public const TWIG_VIEW = 0;
    public const REACT_VIEW = 1;

    /**
     * @var string File path of the responded view
     */
    private string $file;
    /**
     * @var array View arguments
     */
    private array $arguments;
    /**
     * @var int Kind of view, see {@link self::TWIG_VIEW} and {@link self::REACT_VIEW}
     */
    private int $kind;

    /**
     * @param int $code
     * @param int $kind
     * @param string $file
     * @param array $arguments
     */
    private function __construct(int $kind, string $file, array $arguments, int $code = HttpCodes::OK) {
        parent::__construct($code);
        $this->kind = $kind;
        $this->file = $file;
        $this->arguments = $arguments;
    }

    public function getViewKind(): int {
        return $this->kind;
    }

    public function getFile(): string {
        return $this->file;
    }

    public function getArguments(): array {
        return $this->arguments;
    }

    /**
     * Create a twig view response
     * @param string $file
     * @param array $arguments
     * @param int $code
     * @return ViewHttpResponse
     */
    public static function twig(string $file, array $arguments, int $code = HttpCodes::OK): ViewHttpResponse {
        return new ViewHttpResponse(self::TWIG_VIEW, $file, $arguments, $code);
    }

    /**
     * Create a react view response
     * @param string $file
     * @param array $arguments
     * @param int $code
     * @return ViewHttpResponse
     */
    public static function react(string $file, array $arguments, int $code = HttpCodes::OK): ViewHttpResponse {
        return new ViewHttpResponse(self::REACT_VIEW, $file, $arguments, $code);
    }

}