<?php
namespace App\Model;
use App\Data\Color;
use App\Gateway\TeamGateway;

/**
 *
 */
class TeamModel /* throw des exceptions(ex validation des champs, filtre etc) pour le controller qui l'utilise, catch celle de la gw,  */
{

    /**
     * Attributes used to handle errors
     */
    public const ERROR_INVALID_COLOR = 0;
    public const ERROR_INVALID_NAME = 1;
    public const ERROR_INVALID_PICTURE = 2;
    public const ERROR_INVALID_SEARCH = 3;
    public const ERROR_NO_DATA_FOUND = 4;

    private TeamGateway $gateway;

    /**
     * @param TeamGateway $gateway
     */
    public function __construct(TeamGateway $gateway)
    {
        $this->gateway = $gateway;
    }

    public function createTeam(string $name,string $picture,int $mainColorValue, int $secondColorValue, array $errors) {

        $mainColor = Color::tryFrom($mainColorValue);
        $secondColor = Color::tryFrom($secondColorValue);
        if( $mainColor == null || $secondColor == null ){
            $errors[] = self::ERROR_INVALID_COLOR;
        }

        if(Validation::hasHTMLInjection($name)){
            $errors[] = self::ERROR_INVALID_NAME;
        }

        if(filter_var($picture,FILTER_VALIDATE_URL)){
            $errors[] = self::ERROR_INVALID_PICTURE;
        }

        if(empty($errors)){
            $this->gateway->insert($name,$picture,$mainColor,$secondColor);
        }

    }

    public function listByName(string $name,array $errors):?array {
        if(Validation::hasHTMLInjection($name)){
            $errors = self::ERROR_INVALID_SEARCH;
        }
        $results = $this->gateway->listByName($name);
        if(empty($results)){
            $errors = self::ERROR_NO_DATA_FOUND;
        }
        if(!empty($errors)){
            return $results;
        }
        return null;
    }
}