<?php

namespace App\Validation;

/**
 * Utility class for validation
 */
class Validation {

    /**
     * Validate a value from validators, appending failures in the given errors array.
     * @param mixed $val the value to validate
     * @param string $valName the name of the value
     * @param array $failures array to push when a validator fails
     * @param Validator ...$validators given validators
     * @return bool true if any of the given validators did fail
     */
    public static function validate($val, string $valName, array &$failures, Validator...$validators): bool {
        $had_errors = false;
        foreach ($validators as $validator) {
            $error = $validator->validate($valName, $val);
            if ($error != null) {
                $failures = array_merge($failures, $error);
                $had_errors = true;
            }
        }
        return $had_errors;
    }

}