<?php

namespace App\Validation;

/**
 * A collection of standard validators
 */
class Validators {

    /**
     * @return Validator a validator that validates a given regex
     */
    public static function regex(string $regex, string $msg = null): Validator {
        return new SimpleFunctionValidator(
            fn(string $str) => preg_match($regex, $str),
            fn(string $name) => [new FieldValidationFail($name, $msg == null ? "field does not validates pattern $regex" : $msg)]
        );
    }

    /**
     * @return Validator a validator that validates strings that only contains numbers, letters, accents letters, `-` and `_`.
     */
    public static function name($msg = null): Validator {
        return self::regex("/^[0-9a-zA-Zà-üÀ-Ü_-]*$/", $msg);
    }

    /**
     * @return Validator a validator that validates strings that only contains numbers, letters, accents letters, `-`, `_` and spaces.
     */
    public static function nameWithSpaces(): Validator {
        return self::regex("/^[0-9a-zA-Zà-üÀ-Ü _-]*$/");
    }

    /**
     * Validate string if its length is between given range
     * @param int $min minimum accepted length, inclusive
     * @param int $max maximum accepted length, exclusive
     * @return Validator
     */
    public static function lenBetween(int $min, int $max): Validator {
        return new FunctionValidator(
            function (string $fieldName, string $str) use ($min, $max) {
                $len = strlen($str);
                if ($len >= $max) {
                    return [new FieldValidationFail($fieldName, "field is longer than $max chars.")];
                }
                if ($len < $min) {
                    return [new FieldValidationFail($fieldName, "field is shorted than $min chars.")];
                }
                return [];
            }
        );
    }
}